==> brevo_1_3.zip: plugins/sibmail/lang/sibmail_fr.php <==
<?php
/*******************************************************************************\
 * SIBMAIL, plugin et squelette pour SPIP - https://www.spip.net/              *
 *         dédié à la gestion de mails via Sendinblue (Brevo)                  *
 *                                                                             *
 *         Copyright (C) 2023 Renaud LAURETTE                                  *
 *                                                                             *
\*******************************************************************************/


// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'attention_inscription' => 'Attention: ne PAS activer l\'inscription automatique avant d\'avoir renseigné TOUS les autres champs !',
	
	// C
	'campagne_creee' => 'Campagne de mailing créée et activée (N° @num@)',
	'code_securite_invalide' => 'Code de sécurité invalide',
	'confirmer_inscription' => 'Un email vous a été envoyé. Veuillez le consulter et confirmer votre inscription.',

	// CFG
	'cfg_titre_sendinblue' => 'Paramètres de l\'interface Brevo',
	
	'cfg_apikey' => 'Clé API principale',
	'cfg_apikey_explication' => 'apikey pour Brevo',
	'cfg_makey' => 'Clé API marketing',
	'cfg_makey_explication' => 'Clé API Brevo marketing automation',
	'cfg_liste_inscrits' => 'Liste des inscrits',
	'cfg_liste_inscrits_explication' => 'Numéro de la liste Brevo regroupant les personnes disposant d\'un compte sur le site',	
	'cfg_inscription_automatique' => 'Inscription automatique ?',
	'cfg_inscription_automatique_explication' => 'Si la case est cochée, les données des auteurs et visiteurs sont propagées vers Brevo lors de la création ou de la modification de leur profil sur ce site.',	
	'cfg_activer_transactionnel' => 'Activer les événements transactionnels ?',
	'cfg_activer_transactionnel_explication' => 'Si la case est cochée, les événements sont propagés vers Brevo.',	
	'cfg_propager_adherents' => 'Activer la propagation des adhérents ?',
	'cfg_propager_adherents_explication' => 'Si la case est cochée, les adhérents enregistrés via HelloAsso seront propagés vers Brevo.',	
	'cfg_attribut_pseudo' => 'Attribut Pseudo',
	'cfg_attribut_pseudo_explication' => 'Nom de l\'attribut de contact Brevo qui reçoit le pseudo de l\'auteur pour ce site',
	'cfg_attribut_statut' => 'Attribut Statut',
	'cfg_attribut_statut_explication' => 'Nom de l\'attribut de contact Brevo qui reçoit le statut de l\'auteur pour ce site',
	'cfg_template_doi' => 'Numéro de modèle DOI',
	'cfg_template_doi_explication' => 'Numéro du modèle de message Brevo envoyé au visiteur souhaitant s\'abonner à une ou plusieurs listes (DOI="Double Opt-In")',
	'cfg_url_doi' => 'URL DOI',
	'cfg_url_doi_explication' => 'URL complète de la page du site vers laquelle sera redirigé le visiteur ayant confirmé son abonnement',
	'cfg_dossier_abonnement' => 'Dossier abonnement',
	'cfg_dossier_abonnement_explication' => 'Numéro du dossier Brevo contenant les listes auxquelles un visiteur peut s\'abonner',
	'cfg_listes_exclues' => 'Listes exclues',
	'cfg_listes_exclues_explication' => 'Identifiants Brevo, séparés par des virgules, des listes exclues de la diffusion des lettres d\'actualités',
	
	// E
	'echec_creation_campagne' => 'Echec lors de la création de la campagne de mailing',
	'echec_activation_campagne' => 'La campagne de mailing a été créée (N° @num@), mais son activation a échoué. Connectez-vous à Brevo pour l\'activer manuellement.',
	'err_pb_from_ou_to' => 'Impossible d\'identifier l\'expediteur "@from@" ou la liste destinataire "@to@".',
	
	 //P
	 'piratage' => 'Piratage ?',
	 
	 // Rapport_campagne
	 'rep_campaign' => 'Campagne',
	 'rep_id' => 'Identifiant',
	 'rep_name' => 'Nom',
	 'rep_status' => 'Statut',
	 'rep_sender' => 'Expéditeur',
	 'rep_replyto' => 'Répondre à',
	 'rep_subject' => 'Sujet',
	 'rep_previewtext' => 'Texte de prévisualisation',
	 'rep_tag' => 'Etiquette',
	 'rep_createdat' => 'Créée le',
	 'rep_sentdate' => 'Envoyée le',
	 'rep_sharelink' => 'Lien vers le contenu',
	 'rep_body' => 'Contenu',
	 'rep_links' => 'Liens internes',
	 
	 'rep_list' => 'Liste',
	 'rep_list_sent' => 'Nombre d\'envois',
	 'rep_list_delivered' => 'Personnes ayant reçu',
	 'rep_list_viewers' => 'Personnes ayant ouvert',
	 'rep_list_views' => 'ouvertures',
	 'rep_list_clickers' => 'Personnes ayant cliqué',
	 'rep_list_clicks' => 'clics',
	 
     // Statuts
	'6forum' => 'Observateur',
	'1comite' => 'Rédacteur',
	'0minirezo' => 'Administrateur',
	'sympathisant' => 'Sympathisant',	
	
	// T
	'titre_page_configurer_sibmail' => 'Configuration de Sibmail',
	
);

==> brevo_1_4.zip: plugins/sibmail/lang/sibmail_fr.php <==
<?php
/*******************************************************************************\
 * SIBMAIL, plugin et squelette pour SPIP - https://www.spip.net/              *
 *         dédié à la gestion de mails via Sendinblue (Brevo)                  *
 *                                                                             *
 *         Copyright (C) 2023 Renaud LAURETTE                                  *
 *                                                                             *
\*******************************************************************************/


// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'attention_inscription' => 'Attention: ne PAS activer l\'inscription automatique avant d\'avoir renseigné TOUS les autres champs !',
	'acces_interdit' => 'Accès interdit',
	
	// C
	'campagne_creee' => 'Campagne de mailing créée et activée (<a href="spip.php?page=@statut@&id=@num@">N° @num@</a>)',
	'code_securite_invalide' => 'Code de sécurité invalide',
	'confirmer_inscription' => 'Un email vous a été envoyé. Veuillez le consulter et confirmer votre inscription.',
	'contacts_de' => 'Contacts de la liste',
	
	// CFG
	'cfg_titre_sendinblue' => 'Paramètres de l\'interface Brevo',
	
	'cfg_apikey' => 'Clé API principale',
	'cfg_apikey_explication' => 'apikey pour Brevo',
	'cfg_makey' => 'Clé API marketing',
	'cfg_makey_explication' => 'Clé API Brevo marketing automation',
	'cfg_liste_inscrits' => 'Liste des inscrits',
	'cfg_liste_inscrits_explication' => 'Numéro de la liste Brevo regroupant les personnes disposant d\'un compte sur le site',	
	'cfg_inscription_automatique' => 'Inscription automatique ?',
	'cfg_inscription_automatique_explication' => 'Si la case est cochée, les données des auteurs et visiteurs sont propagées vers Brevo lors de la création ou de la modification de leur profil sur ce site.',	
	'cfg_activer_transactionnel' => 'Activer les événements transactionnels ?',
	'cfg_activer_transactionnel_explication' => 'Si la case est cochée, les événements sont propagés vers Brevo.',	
	'cfg_propager_adherents' => 'Activer la propagation des adhérents ?',
	'cfg_propager_adherents_explication' => 'Si la case est cochée, les adhérents enregistrés via HelloAsso seront propagés vers Brevo.',	
	'cfg_attribut_pseudo' => 'Attribut Pseudo',
	'cfg_attribut_pseudo_explication' => 'Nom de l\'attribut de contact Brevo qui reçoit le pseudo de l\'auteur pour ce site',
	'cfg_attribut_statut' => 'Attribut Statut',
	'cfg_attribut_statut_explication' => 'Nom de l\'attribut de contact Brevo qui reçoit le statut de l\'auteur pour ce site',
	'cfg_template_doi' => 'Numéro de modèle DOI',
	'cfg_template_doi_explication' => 'Numéro du modèle de message Brevo envoyé au visiteur souhaitant s\'abonner à une ou plusieurs listes (DOI="Double Opt-In")',
	'cfg_url_doi' => 'URL DOI',
	'cfg_url_doi_explication' => 'URL complète de la page du site vers laquelle sera redirigé le visiteur ayant confirmé son abonnement',
	'cfg_dossier_abonnement' => 'Dossier abonnement',
	'cfg_dossier_abonnement_explication' => 'Numéro du dossier Brevo contenant les listes auxquelles un visiteur peut s\'abonner',
	'cfg_listes_exclues' => 'Listes exclues',
	'cfg_listes_exclues_explication' => 'Identifiants Brevo, séparés par des virgules, des listes exclues de la diffusion des lettres d\'actualités',
	
	// E
	'echec_creation_campagne' => 'Echec lors de la création de la campagne de mailing',
	'echec_activation_campagne' => 'La campagne de mailing a été créée (N° @num@), mais son activation a échoué. Connectez-vous à Brevo pour l\'activer manuellement.',
	'err_pb_from_ou_to' => 'Impossible d\'identifier l\'expediteur "@from@" ou la liste destinataire "@to@".',
	'explication_acces_interdit' => 'Vous n\'avez pas les droits suffisants pour exécuter cette requête.',
	
	 //P
	 'piratage' => 'Piratage ?',
	 
	 // Rapport_campagne
	 'rep_campaign' => 'Campagne',
	 'rep_id' => 'Identifiant',
	 'rep_name' => 'Nom',
	 'rep_status' => 'Statut',
	 'rep_sender' => 'Expéditeur',
	 'rep_replyto' => 'Répondre à',
	 'rep_subject' => 'Sujet',
	 'rep_previewtext' => 'Texte de prévisualisation',
	 'rep_tag' => 'Etiquette',
	 'rep_createdat' => 'Créée le',
	 'rep_sentdate' => 'Envoyée le',
	 'rep_sharelink' => 'Lien vers le contenu',
	 'rep_body' => 'Contenu',
	 'rep_links' => 'Liens internes',
	 
	 'rep_list' => 'Liste',
	 'rep_list_sent' => 'Nombre d\'envois',
	 'rep_list_delivered' => 'Personnes ayant reçu',
	 'rep_list_viewers' => 'Personnes ayant ouvert',
	 'rep_list_views' => 'ouvertures',
	 'rep_list_clickers' => 'Personnes ayant cliqué',
	 'rep_list_clicks' => 'clics',
	 
     // Statuts
	'6forum' => 'Observateur',
	'1comite' => 'Rédacteur',
	'0minirezo' => 'Administrateur',
	'sympathisant' => 'Sympathisant',	
	
	// T
	'titre_page_configurer_sibmail' => 'Configuration de Sibmail',
	
);
